from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from stackl_client.api.about_api import AboutApi
from stackl_client.api.configurator_api import ConfiguratorApi
from stackl_client.api.documents_api import DocumentsApi
from stackl_client.api.functional_requirements_api import FunctionalRequirementsApi
from stackl_client.api.policy_agent_api import PolicyAgentApi
from stackl_client.api.policy_templates_api import PolicyTemplatesApi
from stackl_client.api.services_api import ServicesApi
from stackl_client.api.stack_application_templates_api import StackApplicationTemplatesApi
from stackl_client.api.stack_infrastructure_templates_api import StackInfrastructureTemplatesApi
from stackl_client.api.stack_instances_api import StackInstancesApi



# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.policy_agent_api import PolicyAgentApi  # noqa: E501
from stackl_client.rest import ApiException


class TestPolicyAgentApi(unittest.TestCase):
    """PolicyAgentApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.policy_agent_api.PolicyAgentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_data(self):
        """Test case for delete_data

        Delete Data  # noqa: E501
        """
        pass

    def test_delete_policy(self):
        """Test case for delete_policy

        Delete Policy  # noqa: E501
        """
        pass

    def test_get_agent_policies(self):
        """Test case for get_agent_policies

        Get Agent Policies  # noqa: E501
        """
        pass

    def test_get_data(self):
        """Test case for get_data

        Get Data  # noqa: E501
        """
        pass

    def test_get_sat_data_from_sat(self):
        """Test case for get_sat_data_from_sat

        Get Sat Data From Sat  # noqa: E501
        """
        pass

    def test_get_sat_policies_from_sat(self):
        """Test case for get_sat_policies_from_sat

        Get Sat Policies From Sat  # noqa: E501
        """
        pass

    def test_get_sit_data_from_sit(self):
        """Test case for get_sit_data_from_sit

        Get Sit Data From Sit  # noqa: E501
        """
        pass

    def test_get_sit_policies_from_sit(self):
        """Test case for get_sit_policies_from_sit

        Get Sit Policies From Sit  # noqa: E501
        """
        pass

    def test_put_data(self):
        """Test case for put_data

        Put Data  # noqa: E501
        """
        pass

    def test_put_sat_policies(self):
        """Test case for put_sat_policies

        Put Sat Policies  # noqa: E501
        """
        pass

    def test_put_sit_policies(self):
        """Test case for put_sit_policies

        Put Sit Policies  # noqa: E501
        """
        pass

    def test_run_query_for_sit_and_sat(self):
        """Test case for run_query_for_sit_and_sat

        Run Query For Sit And Sat  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.functional_requirements_api import FunctionalRequirementsApi  # noqa: E501
from stackl_client.rest import ApiException


class TestFunctionalRequirementsApi(unittest.TestCase):
    """FunctionalRequirementsApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.functional_requirements_api.FunctionalRequirementsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_functional_requirement(self):
        """Test case for delete_functional_requirement

        Delete Functional Requirement  # noqa: E501
        """
        pass

    def test_get_functional_requirement_by_name(self):
        """Test case for get_functional_requirement_by_name

        Get Functional Requirement By Name  # noqa: E501
        """
        pass

    def test_get_functional_requirements(self):
        """Test case for get_functional_requirements

        Get Functional Requirements  # noqa: E501
        """
        pass

    def test_post_functional_requirement(self):
        """Test case for post_functional_requirement

        Post Functional Requirement  # noqa: E501
        """
        pass

    def test_put_functional_requirement(self):
        """Test case for put_functional_requirement

        Put Functional Requirement  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from stackl_client.models.collection_document import CollectionDocument
from stackl_client.models.functional_requirement import FunctionalRequirement
from stackl_client.models.http_validation_error import HTTPValidationError
from stackl_client.models.infrastructure_base_document import InfrastructureBaseDocument
from stackl_client.models.infrastructure_target import InfrastructureTarget
from stackl_client.models.invocation import Invocation
from stackl_client.models.policy_template import PolicyTemplate
from stackl_client.models.service import Service
from stackl_client.models.stack_application_template import StackApplicationTemplate
from stackl_client.models.stack_infrastructure_template import StackInfrastructureTemplate
from stackl_client.models.stack_instance import StackInstance
from stackl_client.models.stack_instance_invocation import StackInstanceInvocation
from stackl_client.models.stack_instance_service import StackInstanceService
from stackl_client.models.stack_instance_status import StackInstanceStatus
from stackl_client.models.stack_instance_update import StackInstanceUpdate
from stackl_client.models.validation_error import ValidationError



# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.policy_templates_api import PolicyTemplatesApi  # noqa: E501
from stackl_client.rest import ApiException


class TestPolicyTemplatesApi(unittest.TestCase):
    """PolicyTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.policy_templates_api.PolicyTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_policy_template_by_name(self):
        """Test case for get_policy_template_by_name

        Get Policy Template By Name  # noqa: E501
        """
        pass

    def test_get_policy_templates(self):
        """Test case for get_policy_templates

        Get Policy Templates  # noqa: E501
        """
        pass

    def test_put_policy_template(self):
        """Test case for put_policy_template

        Put Policy Template  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import stackl_client
from stackl_client.models.stack_application_template import StackApplicationTemplate  # noqa: E501
from stackl_client.rest import ApiException

class TestStackApplicationTemplate(unittest.TestCase):
    """StackApplicationTemplate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StackApplicationTemplate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = stackl_client.models.stack_application_template.StackApplicationTemplate()  # noqa: E501
        if include_optional :
            return StackApplicationTemplate(
                name = '0', 
                description = '0', 
                services = [
                    '0'
                    ], 
                extra_functional_requirements = stackl_client.models.extra_functional_requirements.Extra Functional Requirements(), 
                category = 'configs', 
                type = 'stack_application_template'
            )
        else :
            return StackApplicationTemplate(
                name = '0',
                services = [
                    '0'
                    ],
        )

    def testStackApplicationTemplate(self):
        """Test StackApplicationTemplate"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stackl_client.configuration import Configuration


class StackInstanceInvocation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'params': 'object',
        'tags': 'dict(str, str)',
        'stack_infrastructure_template': 'str',
        'stack_application_template': 'str',
        'stack_instance_name': 'str',
        'secrets': 'object',
        'replicas': 'dict(str, int)'
    }

    attribute_map = {
        'params': 'params',
        'tags': 'tags',
        'stack_infrastructure_template': 'stack_infrastructure_template',
        'stack_application_template': 'stack_application_template',
        'stack_instance_name': 'stack_instance_name',
        'secrets': 'secrets',
        'replicas': 'replicas'
    }

    def __init__(self, params=None, tags=None, stack_infrastructure_template='stackl', stack_application_template='web', stack_instance_name='default_test_instance', secrets=None, replicas=None, local_vars_configuration=None):  # noqa: E501
        """StackInstanceInvocation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._params = None
        self._tags = None
        self._stack_infrastructure_template = None
        self._stack_application_template = None
        self._stack_instance_name = None
        self._secrets = None
        self._replicas = None
        self.discriminator = None

        if params is not None:
            self.params = params
        if tags is not None:
            self.tags = tags
        if stack_infrastructure_template is not None:
            self.stack_infrastructure_template = stack_infrastructure_template
        if stack_application_template is not None:
            self.stack_application_template = stack_application_template
        if stack_instance_name is not None:
            self.stack_instance_name = stack_instance_name
        if secrets is not None:
            self.secrets = secrets
        if replicas is not None:
            self.replicas = replicas

    @property
    def params(self):
        """Gets the params of this StackInstanceInvocation.  # noqa: E501


        :return: The params of this StackInstanceInvocation.  # noqa: E501
        :rtype: object
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this StackInstanceInvocation.


        :param params: The params of this StackInstanceInvocation.  # noqa: E501
        :type: object
        """

        self._params = params

    @property
    def tags(self):
        """Gets the tags of this StackInstanceInvocation.  # noqa: E501


        :return: The tags of this StackInstanceInvocation.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this StackInstanceInvocation.


        :param tags: The tags of this StackInstanceInvocation.  # noqa: E501
        :type: dict(str, str)
        """

        self._tags = tags

    @property
    def stack_infrastructure_template(self):
        """Gets the stack_infrastructure_template of this StackInstanceInvocation.  # noqa: E501


        :return: The stack_infrastructure_template of this StackInstanceInvocation.  # noqa: E501
        :rtype: str
        """
        return self._stack_infrastructure_template

    @stack_infrastructure_template.setter
    def stack_infrastructure_template(self, stack_infrastructure_template):
        """Sets the stack_infrastructure_template of this StackInstanceInvocation.


        :param stack_infrastructure_template: The stack_infrastructure_template of this StackInstanceInvocation.  # noqa: E501
        :type: str
        """

        self._stack_infrastructure_template = stack_infrastructure_template

    @property
    def stack_application_template(self):
        """Gets the stack_application_template of this StackInstanceInvocation.  # noqa: E501


        :return: The stack_application_template of this StackInstanceInvocation.  # noqa: E501
        :rtype: str
        """
        return self._stack_application_template

    @stack_application_template.setter
    def stack_application_template(self, stack_application_template):
        """Sets the stack_application_template of this StackInstanceInvocation.


        :param stack_application_template: The stack_application_template of this StackInstanceInvocation.  # noqa: E501
        :type: str
        """

        self._stack_application_template = stack_application_template

    @property
    def stack_instance_name(self):
        """Gets the stack_instance_name of this StackInstanceInvocation.  # noqa: E501


        :return: The stack_instance_name of this StackInstanceInvocation.  # noqa: E501
        :rtype: str
        """
        return self._stack_instance_name

    @stack_instance_name.setter
    def stack_instance_name(self, stack_instance_name):
        """Sets the stack_instance_name of this StackInstanceInvocation.


        :param stack_instance_name: The stack_instance_name of this StackInstanceInvocation.  # noqa: E501
        :type: str
        """

        self._stack_instance_name = stack_instance_name

    @property
    def secrets(self):
        """Gets the secrets of this StackInstanceInvocation.  # noqa: E501


        :return: The secrets of this StackInstanceInvocation.  # noqa: E501
        :rtype: object
        """
        return self._secrets

    @secrets.setter
    def secrets(self, secrets):
        """Sets the secrets of this StackInstanceInvocation.


        :param secrets: The secrets of this StackInstanceInvocation.  # noqa: E501
        :type: object
        """

        self._secrets = secrets

    @property
    def replicas(self):
        """Gets the replicas of this StackInstanceInvocation.  # noqa: E501


        :return: The replicas of this StackInstanceInvocation.  # noqa: E501
        :rtype: dict(str, int)
        """
        return self._replicas

    @replicas.setter
    def replicas(self, replicas):
        """Sets the replicas of this StackInstanceInvocation.


        :param replicas: The replicas of this StackInstanceInvocation.  # noqa: E501
        :type: dict(str, int)
        """

        self._replicas = replicas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StackInstanceInvocation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StackInstanceInvocation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.configurator_api import ConfiguratorApi  # noqa: E501
from stackl_client.rest import ApiException


class TestConfiguratorApi(unittest.TestCase):
    """ConfiguratorApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.configurator_api.ConfiguratorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_configurator_file(self):
        """Test case for delete_configurator_file

        Delete Configurator File  # noqa: E501
        """
        pass

    def test_get_configurator_file(self):
        """Test case for get_configurator_file

        Get Configurator File  # noqa: E501
        """
        pass

    def test_post_configurator_file(self):
        """Test case for post_configurator_file

        Post Configurator File  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.services_api import ServicesApi  # noqa: E501
from stackl_client.rest import ApiException


class TestServicesApi(unittest.TestCase):
    """ServicesApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.services_api.ServicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_service(self):
        """Test case for delete_service

        Delete Service  # noqa: E501
        """
        pass

    def test_get_service_by_name(self):
        """Test case for get_service_by_name

        Get Service By Name  # noqa: E501
        """
        pass

    def test_get_services(self):
        """Test case for get_services

        Get Services  # noqa: E501
        """
        pass

    def test_post_service(self):
        """Test case for post_service

        Post Service  # noqa: E501
        """
        pass

    def test_put_service(self):
        """Test case for put_service

        Put Service  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stackl_client.configuration import Configuration


class Policy(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'description': 'str',
        'category': 'str',
        'type': 'str',
        'policy': 'str',
        'inputs': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'category': 'category',
        'type': 'type',
        'policy': 'policy',
        'inputs': 'inputs'
    }

    def __init__(self, name=None, description=None, category='configs', type='policy', policy=None, inputs=None, local_vars_configuration=None):  # noqa: E501
        """Policy - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._description = None
        self._category = None
        self._type = None
        self._policy = None
        self._inputs = None
        self.discriminator = None

        self.name = name
        if description is not None:
            self.description = description
        if category is not None:
            self.category = category
        if type is not None:
            self.type = type
        self.policy = policy
        self.inputs = inputs

    @property
    def name(self):
        """Gets the name of this Policy.  # noqa: E501


        :return: The name of this Policy.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Policy.


        :param name: The name of this Policy.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Policy.  # noqa: E501


        :return: The description of this Policy.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Policy.


        :param description: The description of this Policy.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def category(self):
        """Gets the category of this Policy.  # noqa: E501


        :return: The category of this Policy.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Policy.


        :param category: The category of this Policy.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def type(self):
        """Gets the type of this Policy.  # noqa: E501


        :return: The type of this Policy.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Policy.


        :param type: The type of this Policy.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def policy(self):
        """Gets the policy of this Policy.  # noqa: E501


        :return: The policy of this Policy.  # noqa: E501
        :rtype: str
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this Policy.


        :param policy: The policy of this Policy.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and policy is None:  # noqa: E501
            raise ValueError("Invalid value for `policy`, must not be `None`")  # noqa: E501

        self._policy = policy

    @property
    def inputs(self):
        """Gets the inputs of this Policy.  # noqa: E501


        :return: The inputs of this Policy.  # noqa: E501
        :rtype: list[str]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this Policy.


        :param inputs: The inputs of this Policy.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and inputs is None:  # noqa: E501
            raise ValueError("Invalid value for `inputs`, must not be `None`")  # noqa: E501

        self._inputs = inputs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Policy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Policy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.terraform_api import TerraformApi  # noqa: E501
from stackl_client.rest import ApiException


class TestTerraformApi(unittest.TestCase):
    """TerraformApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.terraform_api.TerraformApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_terraform_statefile(self):
        """Test case for delete_terraform_statefile

        Delete Terraform Statefile  # noqa: E501
        """
        pass

    def test_get_terraform_statefile(self):
        """Test case for get_terraform_statefile

        Get Terraform Statefile  # noqa: E501
        """
        pass

    def test_post_terraform_statefile(self):
        """Test case for post_terraform_statefile

        Post Terraform Statefile  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from stackl_client.api.about_api import AboutApi
from stackl_client.api.configurator_api import ConfiguratorApi
from stackl_client.api.documents_api import DocumentsApi
from stackl_client.api.functional_requirements_api import FunctionalRequirementsApi
from stackl_client.api.policy_agent_api import PolicyAgentApi
from stackl_client.api.policy_templates_api import PolicyTemplatesApi
from stackl_client.api.services_api import ServicesApi
from stackl_client.api.stack_application_templates_api import StackApplicationTemplatesApi
from stackl_client.api.stack_infrastructure_templates_api import StackInfrastructureTemplatesApi
from stackl_client.api.stack_instances_api import StackInstancesApi

# import ApiClient
from stackl_client.api_client import ApiClient
from stackl_client.configuration import Configuration
from stackl_client.exceptions import OpenApiException
from stackl_client.exceptions import ApiTypeError
from stackl_client.exceptions import ApiValueError
from stackl_client.exceptions import ApiKeyError
from stackl_client.exceptions import ApiException
# import models into sdk package
from stackl_client.models.collection_document import CollectionDocument
from stackl_client.models.functional_requirement import FunctionalRequirement
from stackl_client.models.http_validation_error import HTTPValidationError
from stackl_client.models.infrastructure_base_document import InfrastructureBaseDocument
from stackl_client.models.infrastructure_target import InfrastructureTarget
from stackl_client.models.invocation import Invocation
from stackl_client.models.policy_template import PolicyTemplate
from stackl_client.models.service import Service
from stackl_client.models.stack_application_template import StackApplicationTemplate
from stackl_client.models.stack_infrastructure_template import StackInfrastructureTemplate
from stackl_client.models.stack_instance import StackInstance
from stackl_client.models.stack_instance_invocation import StackInstanceInvocation
from stackl_client.models.stack_instance_service import StackInstanceService
from stackl_client.models.stack_instance_status import StackInstanceStatus
from stackl_client.models.stack_instance_update import StackInstanceUpdate
from stackl_client.models.validation_error import ValidationError




# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import stackl_client
from stackl_client.models.stack_instance import StackInstance  # noqa: E501
from stackl_client.rest import ApiException

class TestStackInstance(unittest.TestCase):
    """StackInstance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StackInstance
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = stackl_client.models.stack_instance.StackInstance()  # noqa: E501
        if include_optional :
            return StackInstance(
                name = '0', 
                deleted = True, 
                services = {
                    'key' : stackl_client.models.stack_instance_service.StackInstanceService(
                        infrastructure_target = '0', 
                        provisioning_parameters = stackl_client.models.provisioning_parameters.Provisioning Parameters(), 
                        status = [
                            stackl_client.models.functional_requirement_status.FunctionalRequirementStatus(
                                functional_requirement = '0', 
                                status = 1, 
                                error_message = '0', )
                            ], )
                    }, 
                type = 'stack_instance', 
                category = 'items'
            )
        else :
            return StackInstance(
                name = '0',
        )

    def testStackInstance(self):
        """Test StackInstance"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stackl_client.configuration import Configuration


class StackInstance(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'deleted': 'bool',
        'instance_params': 'object',
        'instance_secrets': 'object',
        'services': 'dict(str, list[StackInstanceService])',
        'stack_infrastructure_template': 'str',
        'stack_application_template': 'str',
        'status': 'list[StackInstanceStatus]',
        'type': 'str',
        'category': 'str'
    }

    attribute_map = {
        'name': 'name',
        'deleted': 'deleted',
        'instance_params': 'instance_params',
        'instance_secrets': 'instance_secrets',
        'services': 'services',
        'stack_infrastructure_template': 'stack_infrastructure_template',
        'stack_application_template': 'stack_application_template',
        'status': 'status',
        'type': 'type',
        'category': 'category'
    }

    def __init__(self, name=None, deleted=False, instance_params=None, instance_secrets=None, services=None, stack_infrastructure_template=None, stack_application_template=None, status=None, type='stack_instance', category='items', local_vars_configuration=None):  # noqa: E501
        """StackInstance - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._deleted = None
        self._instance_params = None
        self._instance_secrets = None
        self._services = None
        self._stack_infrastructure_template = None
        self._stack_application_template = None
        self._status = None
        self._type = None
        self._category = None
        self.discriminator = None

        self.name = name
        if deleted is not None:
            self.deleted = deleted
        if instance_params is not None:
            self.instance_params = instance_params
        if instance_secrets is not None:
            self.instance_secrets = instance_secrets
        if services is not None:
            self.services = services
        self.stack_infrastructure_template = stack_infrastructure_template
        self.stack_application_template = stack_application_template
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type
        if category is not None:
            self.category = category

    @property
    def name(self):
        """Gets the name of this StackInstance.  # noqa: E501


        :return: The name of this StackInstance.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StackInstance.


        :param name: The name of this StackInstance.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def deleted(self):
        """Gets the deleted of this StackInstance.  # noqa: E501


        :return: The deleted of this StackInstance.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this StackInstance.


        :param deleted: The deleted of this StackInstance.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def instance_params(self):
        """Gets the instance_params of this StackInstance.  # noqa: E501


        :return: The instance_params of this StackInstance.  # noqa: E501
        :rtype: object
        """
        return self._instance_params

    @instance_params.setter
    def instance_params(self, instance_params):
        """Sets the instance_params of this StackInstance.


        :param instance_params: The instance_params of this StackInstance.  # noqa: E501
        :type: object
        """

        self._instance_params = instance_params

    @property
    def instance_secrets(self):
        """Gets the instance_secrets of this StackInstance.  # noqa: E501


        :return: The instance_secrets of this StackInstance.  # noqa: E501
        :rtype: object
        """
        return self._instance_secrets

    @instance_secrets.setter
    def instance_secrets(self, instance_secrets):
        """Sets the instance_secrets of this StackInstance.


        :param instance_secrets: The instance_secrets of this StackInstance.  # noqa: E501
        :type: object
        """

        self._instance_secrets = instance_secrets

    @property
    def services(self):
        """Gets the services of this StackInstance.  # noqa: E501


        :return: The services of this StackInstance.  # noqa: E501
        :rtype: dict(str, list[StackInstanceService])
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this StackInstance.


        :param services: The services of this StackInstance.  # noqa: E501
        :type: dict(str, list[StackInstanceService])
        """

        self._services = services

    @property
    def stack_infrastructure_template(self):
        """Gets the stack_infrastructure_template of this StackInstance.  # noqa: E501


        :return: The stack_infrastructure_template of this StackInstance.  # noqa: E501
        :rtype: str
        """
        return self._stack_infrastructure_template

    @stack_infrastructure_template.setter
    def stack_infrastructure_template(self, stack_infrastructure_template):
        """Sets the stack_infrastructure_template of this StackInstance.


        :param stack_infrastructure_template: The stack_infrastructure_template of this StackInstance.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and stack_infrastructure_template is None:  # noqa: E501
            raise ValueError("Invalid value for `stack_infrastructure_template`, must not be `None`")  # noqa: E501

        self._stack_infrastructure_template = stack_infrastructure_template

    @property
    def stack_application_template(self):
        """Gets the stack_application_template of this StackInstance.  # noqa: E501


        :return: The stack_application_template of this StackInstance.  # noqa: E501
        :rtype: str
        """
        return self._stack_application_template

    @stack_application_template.setter
    def stack_application_template(self, stack_application_template):
        """Sets the stack_application_template of this StackInstance.


        :param stack_application_template: The stack_application_template of this StackInstance.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and stack_application_template is None:  # noqa: E501
            raise ValueError("Invalid value for `stack_application_template`, must not be `None`")  # noqa: E501

        self._stack_application_template = stack_application_template

    @property
    def status(self):
        """Gets the status of this StackInstance.  # noqa: E501


        :return: The status of this StackInstance.  # noqa: E501
        :rtype: list[StackInstanceStatus]
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this StackInstance.


        :param status: The status of this StackInstance.  # noqa: E501
        :type: list[StackInstanceStatus]
        """

        self._status = status

    @property
    def type(self):
        """Gets the type of this StackInstance.  # noqa: E501


        :return: The type of this StackInstance.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this StackInstance.


        :param type: The type of this StackInstance.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def category(self):
        """Gets the category of this StackInstance.  # noqa: E501


        :return: The category of this StackInstance.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this StackInstance.


        :param category: The category of this StackInstance.  # noqa: E501
        :type: str
        """

        self._category = category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StackInstance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StackInstance):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import stackl_client
from stackl_client.models.stack_instance_status import StackInstanceStatus  # noqa: E501
from stackl_client.rest import ApiException

class TestStackInstanceStatus(unittest.TestCase):
    """StackInstanceStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StackInstanceStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = stackl_client.models.stack_instance_status.StackInstanceStatus()  # noqa: E501
        if include_optional :
            return StackInstanceStatus(
                functional_requirement = '0', 
                infrastructure_target = '0', 
                service = '0', 
                status = [
                    0
                    ], 
                error_message = '0'
            )
        else :
            return StackInstanceStatus(
        )

    def testStackInstanceStatus(self):
        """Test StackInstanceStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.documents_api import DocumentsApi  # noqa: E501
from stackl_client.rest import ApiException


class TestDocumentsApi(unittest.TestCase):
    """DocumentsApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.documents_api.DocumentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_document(self):
        """Test case for delete_document

        Delete Document  # noqa: E501
        """
        pass

    def test_get_document_by_type_and_name(self):
        """Test case for get_document_by_type_and_name

        Get Document By Type And Name  # noqa: E501
        """
        pass

    def test_get_documents_by_type(self):
        """Test case for get_documents_by_type

        Get Documents By Type  # noqa: E501
        """
        pass

    def test_get_types(self):
        """Test case for get_types

        Get Types  # noqa: E501
        """
        pass

    def test_post_document(self):
        """Test case for post_document

        Post Document  # noqa: E501
        """
        pass

    def test_put_document(self):
        """Test case for put_document

        Put Document  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import stackl_client
from stackl_client.models.stack_instance_service import StackInstanceService  # noqa: E501
from stackl_client.rest import ApiException

class TestStackInstanceService(unittest.TestCase):
    """StackInstanceService unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StackInstanceService
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = stackl_client.models.stack_instance_service.StackInstanceService()  # noqa: E501
        if include_optional :
            return StackInstanceService(
                infrastructure_target = '0', 
                provisioning_parameters = stackl_client.models.provisioning_parameters.Provisioning Parameters(), 
                status = [
                    stackl_client.models.functional_requirement_status.FunctionalRequirementStatus(
                        functional_requirement = '0', 
                        status = 1, 
                        error_message = '0', )
                    ]
            )
        else :
            return StackInstanceService(
        )

    def testStackInstanceService(self):
        """Test StackInstanceService"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.stack_infrastructure_templates_api import StackInfrastructureTemplatesApi  # noqa: E501
from stackl_client.rest import ApiException


class TestStackInfrastructureTemplatesApi(unittest.TestCase):
    """StackInfrastructureTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.stack_infrastructure_templates_api.StackInfrastructureTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_stack_infrastructure_template(self):
        """Test case for delete_stack_infrastructure_template

        Delete Stack Infrastructure Template  # noqa: E501
        """
        pass

    def test_get_stack_infrastructure_template_by_name(self):
        """Test case for get_stack_infrastructure_template_by_name

        Get Stack Infrastructure Template By Name  # noqa: E501
        """
        pass

    def test_get_stack_infrastructure_templates(self):
        """Test case for get_stack_infrastructure_templates

        Get Stack Infrastructure Templates  # noqa: E501
        """
        pass

    def test_post_stack_infrastructure_template(self):
        """Test case for post_stack_infrastructure_template

        Post Stack Infrastructure Template  # noqa: E501
        """
        pass

    def test_put_stack_infrastructure_template(self):
        """Test case for put_stack_infrastructure_template

        Put Stack Infrastructure Template  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from stackl_client.api_client import ApiClient
from stackl_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PolicyAgentApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_data(self, **kwargs):  # noqa: E501
        """Delete Data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str data_path:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_data_with_http_info(**kwargs)  # noqa: E501

    def delete_data_with_http_info(self, **kwargs):  # noqa: E501
        """Delete Data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str data_path:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'data_path'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_data" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'data_path' in local_var_params and local_var_params['data_path'] is not None:  # noqa: E501
            query_params.append(('data_path', local_var_params['data_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/data', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_policy(self, **kwargs):  # noqa: E501
        """Delete Policy  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_policy(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str policy_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_policy_with_http_info(**kwargs)  # noqa: E501

    def delete_policy_with_http_info(self, **kwargs):  # noqa: E501
        """Delete Policy  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_policy_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str policy_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'policy_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_policy" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'policy_id' in local_var_params and local_var_params['policy_id'] is not None:  # noqa: E501
            query_params.append(('policy_id', local_var_params['policy_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/policy', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_agent_policies(self, **kwargs):  # noqa: E501
        """Get Agent Policies  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_agent_policies(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_agent_policies_with_http_info(**kwargs)  # noqa: E501

    def get_agent_policies_with_http_info(self, **kwargs):  # noqa: E501
        """Get Agent Policies  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_agent_policies_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_agent_policies" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_data(self, **kwargs):  # noqa: E501
        """Get Data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str data_path:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_data_with_http_info(**kwargs)  # noqa: E501

    def get_data_with_http_info(self, **kwargs):  # noqa: E501
        """Get Data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str data_path:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'data_path'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'data_path' in local_var_params and local_var_params['data_path'] is not None:  # noqa: E501
            query_params.append(('data_path', local_var_params['data_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/data', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sat_data_from_sat(self, **kwargs):  # noqa: E501
        """Get Sat Data From Sat  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sat_data_from_sat(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sat_name:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sat_data_from_sat_with_http_info(**kwargs)  # noqa: E501

    def get_sat_data_from_sat_with_http_info(self, **kwargs):  # noqa: E501
        """Get Sat Data From Sat  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sat_data_from_sat_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sat_name:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sat_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sat_data_from_sat" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'sat_name' in local_var_params and local_var_params['sat_name'] is not None:  # noqa: E501
            query_params.append(('sat_name', local_var_params['sat_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/query/sat_data', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sat_policies_from_sat(self, **kwargs):  # noqa: E501
        """Get Sat Policies From Sat  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sat_policies_from_sat(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sat_name:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sat_policies_from_sat_with_http_info(**kwargs)  # noqa: E501

    def get_sat_policies_from_sat_with_http_info(self, **kwargs):  # noqa: E501
        """Get Sat Policies From Sat  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sat_policies_from_sat_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sat_name:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sat_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sat_policies_from_sat" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'sat_name' in local_var_params and local_var_params['sat_name'] is not None:  # noqa: E501
            query_params.append(('sat_name', local_var_params['sat_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/query/sat_policies', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sit_data_from_sit(self, **kwargs):  # noqa: E501
        """Get Sit Data From Sit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sit_data_from_sit(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sit_name:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sit_data_from_sit_with_http_info(**kwargs)  # noqa: E501

    def get_sit_data_from_sit_with_http_info(self, **kwargs):  # noqa: E501
        """Get Sit Data From Sit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sit_data_from_sit_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sit_name:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sit_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sit_data_from_sit" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'sit_name' in local_var_params and local_var_params['sit_name'] is not None:  # noqa: E501
            query_params.append(('sit_name', local_var_params['sit_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/query/sit_data', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sit_policies_from_sit(self, **kwargs):  # noqa: E501
        """Get Sit Policies From Sit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sit_policies_from_sit(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sit_name:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sit_policies_from_sit_with_http_info(**kwargs)  # noqa: E501

    def get_sit_policies_from_sit_with_http_info(self, **kwargs):  # noqa: E501
        """Get Sit Policies From Sit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sit_policies_from_sit_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sit_name:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sit_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sit_policies_from_sit" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'sit_name' in local_var_params and local_var_params['sit_name'] is not None:  # noqa: E501
            query_params.append(('sit_name', local_var_params['sit_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/query/sit_policies', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_data(self, body, **kwargs):  # noqa: E501
        """Put Data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_data(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param str data_path:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.put_data_with_http_info(body, **kwargs)  # noqa: E501

    def put_data_with_http_info(self, body, **kwargs):  # noqa: E501
        """Put Data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_data_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param str data_path:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body',
            'data_path'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_data" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `put_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'data_path' in local_var_params and local_var_params['data_path'] is not None:  # noqa: E501
            query_params.append(('data_path', local_var_params['data_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/data', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_sat_policies(self, stack_application_template, **kwargs):  # noqa: E501
        """Put Sat Policies  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_sat_policies(stack_application_template, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StackApplicationTemplate stack_application_template: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.put_sat_policies_with_http_info(stack_application_template, **kwargs)  # noqa: E501

    def put_sat_policies_with_http_info(self, stack_application_template, **kwargs):  # noqa: E501
        """Put Sat Policies  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_sat_policies_with_http_info(stack_application_template, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StackApplicationTemplate stack_application_template: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'stack_application_template'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_sat_policies" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'stack_application_template' is set
        if self.api_client.client_side_validation and ('stack_application_template' not in local_var_params or  # noqa: E501
                                                        local_var_params['stack_application_template'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `stack_application_template` when calling `put_sat_policies`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'stack_application_template' in local_var_params:
            body_params = local_var_params['stack_application_template']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/sat', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_sit_policies(self, stack_infrastructure_template, **kwargs):  # noqa: E501
        """Put Sit Policies  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_sit_policies(stack_infrastructure_template, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StackInfrastructureTemplate stack_infrastructure_template: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.put_sit_policies_with_http_info(stack_infrastructure_template, **kwargs)  # noqa: E501

    def put_sit_policies_with_http_info(self, stack_infrastructure_template, **kwargs):  # noqa: E501
        """Put Sit Policies  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_sit_policies_with_http_info(stack_infrastructure_template, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StackInfrastructureTemplate stack_infrastructure_template: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'stack_infrastructure_template'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_sit_policies" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'stack_infrastructure_template' is set
        if self.api_client.client_side_validation and ('stack_infrastructure_template' not in local_var_params or  # noqa: E501
                                                        local_var_params['stack_infrastructure_template'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `stack_infrastructure_template` when calling `put_sit_policies`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'stack_infrastructure_template' in local_var_params:
            body_params = local_var_params['stack_infrastructure_template']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/sit', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def run_query_for_sit_and_sat(self, **kwargs):  # noqa: E501
        """Run Query For Sit And Sat  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.run_query_for_sit_and_sat(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sit_name:
        :param str sat_name:
        :param str query:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.run_query_for_sit_and_sat_with_http_info(**kwargs)  # noqa: E501

    def run_query_for_sit_and_sat_with_http_info(self, **kwargs):  # noqa: E501
        """Run Query For Sit And Sat  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.run_query_for_sit_and_sat_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sit_name:
        :param str sat_name:
        :param str query:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sit_name',
            'sat_name',
            'query'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_query_for_sit_and_sat" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'sit_name' in local_var_params and local_var_params['sit_name'] is not None:  # noqa: E501
            query_params.append(('sit_name', local_var_params['sit_name']))  # noqa: E501
        if 'sat_name' in local_var_params and local_var_params['sat_name'] is not None:  # noqa: E501
            query_params.append(('sat_name', local_var_params['sat_name']))  # noqa: E501
        if 'query' in local_var_params and local_var_params['query'] is not None:  # noqa: E501
            query_params.append(('query', local_var_params['query']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/policy_agent/query', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import stackl_client
from stackl_client.models.base_document import BaseDocument  # noqa: E501
from stackl_client.rest import ApiException

class TestBaseDocument(unittest.TestCase):
    """BaseDocument unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test BaseDocument
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = stackl_client.models.base_document.BaseDocument()  # noqa: E501
        if include_optional :
            return BaseDocument(
                name = '0', 
                category = '0', 
                type = '0', 
                params = stackl_client.models.params.Params(), 
                description = 'Base Document'
            )
        else :
            return BaseDocument(
                name = '0',
                category = '0',
                type = '0',
        )

    def testBaseDocument(self):
        """Test BaseDocument"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stackl_client.configuration import Configuration


class FunctionalRequirement(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'category': 'str',
        'type': 'str',
        'params': 'object',
        'secrets': 'object',
        'description': 'str',
        'invocation': 'Invocation',
        'outputs': 'object'
    }

    attribute_map = {
        'name': 'name',
        'category': 'category',
        'type': 'type',
        'params': 'params',
        'secrets': 'secrets',
        'description': 'description',
        'invocation': 'invocation',
        'outputs': 'outputs'
    }

    def __init__(self, name=None, category=None, type='functional_requirement', params=None, secrets=None, description='Base Document', invocation=None, outputs=None, local_vars_configuration=None):  # noqa: E501
        """FunctionalRequirement - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._category = None
        self._type = None
        self._params = None
        self._secrets = None
        self._description = None
        self._invocation = None
        self._outputs = None
        self.discriminator = None

        self.name = name
        self.category = category
        if type is not None:
            self.type = type
        if params is not None:
            self.params = params
        if secrets is not None:
            self.secrets = secrets
        if description is not None:
            self.description = description
        self.invocation = invocation
        if outputs is not None:
            self.outputs = outputs

    @property
    def name(self):
        """Gets the name of this FunctionalRequirement.  # noqa: E501


        :return: The name of this FunctionalRequirement.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FunctionalRequirement.


        :param name: The name of this FunctionalRequirement.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def category(self):
        """Gets the category of this FunctionalRequirement.  # noqa: E501


        :return: The category of this FunctionalRequirement.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this FunctionalRequirement.


        :param category: The category of this FunctionalRequirement.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and category is None:  # noqa: E501
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def type(self):
        """Gets the type of this FunctionalRequirement.  # noqa: E501


        :return: The type of this FunctionalRequirement.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FunctionalRequirement.


        :param type: The type of this FunctionalRequirement.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def params(self):
        """Gets the params of this FunctionalRequirement.  # noqa: E501


        :return: The params of this FunctionalRequirement.  # noqa: E501
        :rtype: object
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this FunctionalRequirement.


        :param params: The params of this FunctionalRequirement.  # noqa: E501
        :type: object
        """

        self._params = params

    @property
    def secrets(self):
        """Gets the secrets of this FunctionalRequirement.  # noqa: E501


        :return: The secrets of this FunctionalRequirement.  # noqa: E501
        :rtype: object
        """
        return self._secrets

    @secrets.setter
    def secrets(self, secrets):
        """Sets the secrets of this FunctionalRequirement.


        :param secrets: The secrets of this FunctionalRequirement.  # noqa: E501
        :type: object
        """

        self._secrets = secrets

    @property
    def description(self):
        """Gets the description of this FunctionalRequirement.  # noqa: E501


        :return: The description of this FunctionalRequirement.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this FunctionalRequirement.


        :param description: The description of this FunctionalRequirement.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def invocation(self):
        """Gets the invocation of this FunctionalRequirement.  # noqa: E501


        :return: The invocation of this FunctionalRequirement.  # noqa: E501
        :rtype: Invocation
        """
        return self._invocation

    @invocation.setter
    def invocation(self, invocation):
        """Sets the invocation of this FunctionalRequirement.


        :param invocation: The invocation of this FunctionalRequirement.  # noqa: E501
        :type: Invocation
        """
        if self.local_vars_configuration.client_side_validation and invocation is None:  # noqa: E501
            raise ValueError("Invalid value for `invocation`, must not be `None`")  # noqa: E501

        self._invocation = invocation

    @property
    def outputs(self):
        """Gets the outputs of this FunctionalRequirement.  # noqa: E501


        :return: The outputs of this FunctionalRequirement.  # noqa: E501
        :rtype: object
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this FunctionalRequirement.


        :param outputs: The outputs of this FunctionalRequirement.  # noqa: E501
        :type: object
        """

        self._outputs = outputs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FunctionalRequirement):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FunctionalRequirement):
            return True

        return self.to_dict() != other.to_dict()
